#!/usr/bin/env python

#-------------------------------------------------------------------
# Objectives
#-------------------------------------------------------------------
# This is the template to make new configuration files. It contains
# all the PFTs that has been parameterized this far. Select the 
# PFTs you would like to use in your simulation. Note that you will
# need a PFT map that distinguishes the same number of PFTs.
#
# Choose for each forest PFT whether you want age classes or not.
# Have a look at teh model documentation on the wiki to make sure
# you understand the difference between a diameter class (set by
# NCIRC) and an age class (set by NAGEC). If you want to distinguish
# age classes for a PFT, set the value in the column 'has_agec'
# to 'y'. If the value is set to no, the model will use one age class
# has been been the default since the start of ORCHIDEE. If set the
# 'y' the model will distinguish NAGEC number of age classes. The 
# code has been tested for 1 and 4 age classes. When using a different 
# number of age classes the boundaries of the age classes wil have to 
# be set as well. Note that age classes are calculated internally and 
# do not need to be represented in the PFT map.
#
# The first column 'domain' gives the spatial domain for which the 
# parameters have been tested. Parameters may work outside their 
# domain but don be surprised if they don't.
#
# WARNING: the order of the PFTs should match the PFT definition of
# the land cover, forest management, litter raking and species maps.
#
# CODING GUIDELINE: variable names written in capitals are variables
# that will end up in the run.defs

#-------------------------------------------------------------------
# Configure the vegetation. 
#-------------------------------------------------------------------
NAGEC = 4
header = ['domain', 'mtc', 'pft', 'species, genus or biome', 'pft_to_mtc', 'has_agec']
config = [\
  ['Global', 'BareSoil', 'SoilBare', 'Global', 1, 'n'],
  ['Global', 'TropicalBroadLeavedEvergreen', 'BroadLeavedEvergreen',  'Tropical', 2, 'y'], 
  ['Global', 'TropicalBroadLeavedRaingreen', 'BroadLeavedRaingreen',  'Tropical', 3, 'y'], 
  ['Global', 'TemperateNeedleleafEvergreen', 'NeedleleafEvergreen', 'Temperate', 4, 'y'], 
  ['Europe', 'TemperateNeedleleafEvergreen', 'PinusSylvestris', 'Temperate', 4, 'y'],
  ['Europe', 'TemperateNeedleleafEvergreen', 'PinusPinaster', 'Temperate', 4, 'y'],
  ['Europe', 'TemperateNeedleleafEvergreen', 'PiceaSp', 'Temperate', 4, 'y'],
  ['Europe', 'TemperateNeedleleafEvergreen', 'Residual', 'Temperate', 4, 'y'],
  ['Global', 'TemperateBroadLeavedEvergreen', 'BroadLeavedEvergreen', 'Temperate', 5, 'y'],
  ['Europe', 'TemperateBroadLeavedEvergreen', 'QuercusIlexSuber', 'Temperate', 5, 'y'],
  ['Global', 'TemperateBroadLeavedSummergreen', 'BroadLeavedSummergreen', 'Temperate', 6, 'y'],
  ['Europe', 'TemperateBroadLeavedSummergreen', 'BetulaSp', 'Temperate', 6, 'y'],
  ['Europe', 'TemperateBroadLeavedSummergreen', 'FagusSylvatica', 'Temperate', 6, 'y'],
  ['Europe', 'TemperateBroadLeavedSummergreen', 'QuercusRoburPetraea', 'Temperate', 6, 'y'],
  ['Europe', 'TemperateBroadLeavedSummergreen', 'PopulusSp', 'Temperate', 6, 'y'],
  ['Europe', 'TemperateBroadLeavedSummergreen', 'Residual', 'Temperate', 6, 'y'],
  ['Global', 'BorealNeedleleafEvergreen', 'NeedleleafEvergreen', 'Boreal', 7, 'y'],
  ['Europe', 'BorealNeedleleafEvergreen', 'PinusSylvestris', 'Boreal', 7, 'y'],
  ['Europe', 'BorealNeedleleafEvergreen', 'PiceaSp', 'Boreal', 7, 'y'], 
  ['Global', 'BorealBroadLeavedSummergreen', 'BroadLeavedSummergreen', 'Boreal', 8, 'y'],
  ['Europe', 'BorealBroadLeavedSummergreen', 'BetulaSp', 'Boreal', 8, 'y'],
  ['Global', 'BorealNeedleleafSummergreen', 'LarixSp', 'Boreal', 9, 'y'],
  ['Global', 'C3Grass', 'C3Grass', 'Temperate', 10, 'n'],
  ['Global', 'C3Grass', 'C3Grass', 'Tropical', 10, 'n'],
  ['Global', 'C3Grass', 'C3Grass', 'Boreal', 10, 'n'],        
  ['Global', 'C4Grass', 'C4Grass', 'Temperate',11, 'n'],
  ['Global', 'C3Agriculture', 'C3Agriculture', 'Temperate', 12, 'n'],
  ['Global', 'C3Agriculture', 'C3Agriculture', 'Boreal', 12, 'n'],
  ['Global', 'C4Agriculture', 'C4Agriculture', 'Temperate', 13, 'n']]  

